==> flutter_audio_recorder-0.1.1.tar.gz: README-zh_CN.md <==
# flutter_audio_recorder
<p align="left">
  <a href="https://pub.dartlang.org/packages/flutter_audio_recorder"><img alt="pub version" src="https://img.shields.io/pub/v/flutter_audio_recorder.svg?style=flat-square"></a>
</p>

[English](./README.md) | 简体中文

Flutter 录音插件 支持录音/暂停/继续/停止, 可以在录音的同时获取到底层提供的音频信息（如声音强度）.

<img src="https://user-images.githubusercontent.com/10917606/64927086-b2bcda00-d838-11e9-9ab8-bad78a95f02c.gif" width="30%" height="30%" />

## 安装方式
加入 `flutter_audio_recorder` 到你的 `pubspec.yaml`

## iOS权限 
加一条到 plist
```
<key>NSMicrophoneUsageDescription</key>
<string>Can We Use Your Microphone Please</string>
```

## 用法

#### Init初始化 (在`录音前`, 调用`初始化`方法，检查文件有无重复)
```
var recorder = FlutterAudioRecorder("filename", AudioFormat.AAC);
await _recorder.initialized;
```
或者
```
var recorder = FlutterAudioRecorder("filename.mp4"); // .wav .aac .m4a
await _recorder.initialized;
```

#### Start开始录音
```
await recorder.start();
var recording = await recorder.current(channel: 0);
```

#### Current获取当前录音状态信息
```
var current = await recording.current(channel: 0);
// print(current.status);
```
设置一个Timer，定期获取信息（录音结束后，记得`cancel`）
```
new Timer.periodic(tick, (Timer t) async {
        var current = await recording.current(channel: 0);
        // print(current.status);
        setState(() {
        });
      });
```

#### 录音状态 - 数据结构
##### Recording
| Name  | Description |
| ------------- | ------------- |
| path  | String  |
| extension  | String  |
| duration  | Duration  |
| audioFormat  | AudioFormat  |
| metering  | AudioMetering  |
| status  | RecordingStatus  |

##### Recording.metering （声音强度）
| Name  | Description |
| ------------- | ------------- |
| peakPower  | double, 强度极值  |
| averagePower  | double, 强度平均值  |
| isMeteringEnabled  | bool, 是否启用（True）  |

##### Recording.status
`Unset`,`Initialized`,`Recording`,`Paused`,`Stopped`


#### Pause暂停录音
```
await _recorder.pause();
```

#### Resume继续录音
```
await _recorder.resume();
```

#### Stop停止录音 (停止之后 `stop`, 需再次执行 `init` 重新指定新的文件名，以创建新的录音)
```
var result = await _recorder.stop();
File file = widget.localFileSystem.file(result.path);
```

## Example
用Xcode打开Example项目可以查看示例


## Getting Started

This project is a starting point for a Flutter
[plug-in package](https://flutter.dev/developing-packages/),
a specialized package that includes platform-specific implementation code for
Android and/or iOS.

For help getting started with Flutter, view our 
[online documentation](https://flutter.dev/docs), which offers tutorials, 
samples, guidance on mobile development, and a full API reference.

==> flutter_audio_recorder-0.2.0.tar.gz: README-zh_CN.md <==
# flutter_audio_recorder
<p align="left">
  <a href="https://pub.dartlang.org/packages/flutter_audio_recorder"><img alt="pub version" src="https://img.shields.io/pub/v/flutter_audio_recorder.svg?style=flat-square"></a>
  <a href="https://github.com/Solido/awesome-flutter">
     <img alt="Awesome Flutter" src="https://img.shields.io/badge/Awesome-Flutter-blue.svg?longCache=true&style=flat-square" />
</p>

[English](./README.md) | 简体中文

Flutter 录音插件 支持录音/暂停/继续/停止, 可以在录音的同时获取到底层提供的音频信息（如声音强度）.

<img src="https://user-images.githubusercontent.com/10917606/64927086-b2bcda00-d838-11e9-9ab8-bad78a95f02c.gif" width="30%" height="30%" />

## 安装方式
加入 `flutter_audio_recorder` 到你的 `pubspec.yaml`

## iOS权限 
加一条到 plist
```
<key>NSMicrophoneUsageDescription</key>
<string>Can We Use Your Microphone Please</string>
```

## 用法

#### Init初始化 (在`录音前`, 调用`初始化`方法，检查文件有无重复)
```
var recorder = FlutterAudioRecorder("recording20190916", AudioFormat.AAC); // recording20190916.m4a by default
await recorder.initialized;

// note: when extension and format conflicts, AudioFormat will overwrite the extension.
// example: FlutterAudioRecorder("recording20190916.wav", AudioFormat.AAC)
// this will be recording20190916.m4a 

```

##### Audio Extension and Format Mapping
| Audio Format  | Audio Extension |
| ------------- | ------------- |
| AAC  | .m4a .aac .mp4  |
| WAV  | .wav  |

或者
```
var recorder = FlutterAudioRecorder("filename.mp4"); // .wav .aac .m4a
await recorder.initialized;
```

#### Start开始录音
```
await recorder.start();
var recording = await recorder.current(channel: 0);
```

#### Current获取当前录音状态信息
```
var current = await recording.current(channel: 0);
// print(current.status);
```
设置一个Timer，定期获取信息（录音结束后，记得`cancel`）
```
new Timer.periodic(tick, (Timer t) async {
        var current = await recording.current(channel: 0);
        // print(current.status);
        setState(() {
        });
      });
```

#### 录音状态 - 数据结构
##### Recording
| Name  | Description |
| ------------- | ------------- |
| path  | String  |
| extension  | String  |
| duration  | Duration  |
| audioFormat  | AudioFormat  |
| metering  | AudioMetering  |
| status  | RecordingStatus  |

##### Recording.metering （声音强度）
| Name  | Description |
| ------------- | ------------- |
| peakPower  | double, 强度极值  |
| averagePower  | double, 强度平均值  |
| isMeteringEnabled  | bool, 是否启用（True）  |

##### Recording.status
`Unset`,`Initialized`,`Recording`,`Paused`,`Stopped`


#### Pause暂停录音
```
await recorder.pause();
```

#### Resume继续录音
```
await recorder.resume();
```

#### Stop停止录音 (停止之后 `stop`, 需再次执行 `init` 重新指定新的文件名，以创建新的录音)
```
var result = await recorder.stop();
File file = widget.localFileSystem.file(result.path);
```

## Example
用Xcode打开Example项目可以查看示例


## Getting Started

This project is a starting point for a Flutter
[plug-in package](https://flutter.dev/developing-packages/),
a specialized package that includes platform-specific implementation code for
Android and/or iOS.

For help getting started with Flutter, view our 
[online documentation](https://flutter.dev/docs), which offers tutorials, 
samples, guidance on mobile development, and a full API reference.
